@@ -98,6 +98,10 @@ void DeepSkyComponent::loadData()
         ingc = line.mid( 1, 4 ).toInt();  // NGC/IC catalog number
         if ( ingc==0 ) cat.clear(); //object is not in NGC or IC catalogs
 
+        QString suffix = line.at( 5 );
+        if ( suffix  == " " )
+            suffix = QString(); // Empty string for no suffix
+
         //coordinates
         rah = line.mid( 6, 2 ).toInt();
         ram = line.mid( 8, 2 ).toInt();
@@ -163,16 +167,16 @@ void DeepSkyComponent::loadData()
         QString snum;
         if ( cat=="IC" || cat=="NGC" ) {
             snum.setNum( ingc );
-            name = cat + ' ' + snum;
+            name = cat + ' ' + snum + suffix;
         } else if ( cat=="M" ) {
             snum.setNum( imess );
             name = cat + ' ' + snum;
             if ( cat2=="NGC" ) {
                 snum.setNum( ingc );
-                name2 = cat2 + ' ' + snum;
+                name2 = cat2 + ' ' + snum + suffix;
             } else if ( cat2=="IC" ) {
                 snum.setNum( ingc );
-                name2 = cat2 + ' ' + snum;
+                name2 = cat2 + ' ' + snum + suffix;
             } else {
                 name2.clear();
             }
@@ -235,7 +239,7 @@ void DeepSkyComponent::loadData()
 }
 
 void DeepSkyComponent::mergeSplitFiles() {
-    //If user has downloaded the Steinicke NGC/IC catalog, then it is 
+    //If user has downloaded the Steinicke NGC/IC catalog, then it is
     //split into multiple files.  Concatenate these into a single file.
     QString firstFile = KStandardDirs::locateLocal("appdata", "ngcic01.dat");
     if ( ! QFile::exists( firstFile ) ) return;
@@ -334,7 +338,7 @@ void DeepSkyComponent::drawDeepSkyCatalog( SkyPainter *skyp, bool drawObject,
     double lgmin = log10(MINZOOM);
     double lgmax = log10(MAXZOOM);
     double lgz = log10(Options::zoomFactor());
-    if ( lgz <= 0.75 * lgmax ) 
+    if ( lgz <= 0.75 * lgmax )
         maglim -= (Options::magLimitDrawDeepSky() - Options::magLimitDrawDeepSkyZoomOut() )*(0.75*lgmax - lgz)/(0.75*lgmax - lgmin);
     m_zoomMagLimit = maglim;
 
@@ -374,7 +378,7 @@ void DeepSkyComponent::drawDeepSkyCatalog( SkyPainter *skyp, bool drawObject,
             if ( (size > 1.0 || Options::zoomFactor() > 2000.) &&
                  ( mag < (float)maglim || obj->isCatalogIC() ) )
             {
-    
+
                 bool drawn = skyp->drawDeepSkyObject(obj, drawImage);
                 if ( drawn  && !( m_hideLabels || mag > labelMagLim ) )
                     addLabel( proj->toScreen(obj), obj );
@@ -419,7 +423,7 @@ SkyObject* DeepSkyComponent::findByName( const QString &name ) {
     return nameHash[ name.toLower() ];
 }
 
-void DeepSkyComponent::objectsInArea( QList<SkyObject*>& list, const SkyRegion& region ) 
+void DeepSkyComponent::objectsInArea( QList<SkyObject*>& list, const SkyRegion& region )
 {
     for( SkyRegion::const_iterator it = region.constBegin(); it != region.constEnd(); ++it )
     {
